dig-clvm: DIG L2 CLVM Consensus Engine
Validates spend bundles and computes coin additions/removals for DIG validators. Built as a thin orchestration layer on top of the Chia crate ecosystem.
Re-exports
pub use consensus::build_block_generator;pub use consensus::validate_block;pub use consensus::validate_spend_bundle;pub use consensus::BlockGeneratorResult;pub use consensus::SpendResult;pub use consensus::ValidationConfig;pub use consensus::ValidationContext;pub use consensus::ValidationError;pub use consensus::L1_MAX_COST_PER_SPEND;pub use consensus::L2_MAX_COST_PER_BLOCK;pub use clvm_traits;pub use clvm_utils;pub use clvmr;pub use chia_protocol;pub use chia_consensus;pub use chia_bls;pub use chia_sdk_types;pub use dig_constants;pub use chia_sdk_driver;pub use chia_sdk_coinset;pub use chia_puzzles;
Modules
Structs
- Allocator
- BlsCache
- Bytes
- Coin
- Coin
Record - Coin
Spend - Coin
State - Conditions
- A grow-only list of conditions which can be used when building spend bundles.
- Consensus
Constants - Curried
Program - Network
Constants - DIG network constants.
- NodePtr
- Program
- Public
Key - Secret
Key - Signature
- Spend
- Spend
Bundle - Spend
Context - A wrapper around
Allocatorthat caches puzzles and keeps track of a list ofCoinSpend. It’s used to construct spend bundles in an easy and efficient way. - Tree
Hash
Enums
Constants
- AGG_
SIG_ AMOUNT - AGG_
SIG_ COST - AGG_
SIG_ ME - AGG_
SIG_ PARENT - AGG_
SIG_ PARENT_ AMOUNT - AGG_
SIG_ PARENT_ PUZZLE - AGG_
SIG_ PUZZLE - AGG_
SIG_ PUZZLE_ AMOUNT - AGG_
SIG_ UNSAFE - ASSERT_
BEFORE_ HEIGHT_ ABSOLUTE - ASSERT_
BEFORE_ HEIGHT_ RELATIVE - ASSERT_
BEFORE_ SECONDS_ ABSOLUTE - ASSERT_
BEFORE_ SECONDS_ RELATIVE - ASSERT_
COIN_ ANNOUNCEMENT - ASSERT_
CONCURRENT_ PUZZLE - ASSERT_
CONCURRENT_ SPEND - ASSERT_
EPHEMERAL - ASSERT_
HEIGHT_ ABSOLUTE - ASSERT_
HEIGHT_ RELATIVE - ASSERT_
MY_ AMOUNT - ASSERT_
MY_ BIRTH_ HEIGHT - ASSERT_
MY_ BIRTH_ SECONDS - ASSERT_
MY_ COIN_ ID - ASSERT_
MY_ PARENT_ ID - ASSERT_
MY_ PUZZLEHASH - ASSERT_
PUZZLE_ ANNOUNCEMENT - ASSERT_
SECONDS_ ABSOLUTE - ASSERT_
SECONDS_ RELATIVE - CREATE_
COIN - CREATE_
COIN_ ANNOUNCEMENT - CREATE_
COIN_ COST - CREATE_
PUZZLE_ ANNOUNCEMENT - DIG_
MAINNET - DIG mainnet constants.
- DIG_
TESTNET - DIG testnet constants.
- FREE_
CONDITIONS - GENERIC_
CONDITION_ COST - RECEIVE_
MESSAGE - REMARK
- RESERVE_
FEE - SEND_
MESSAGE - SOFTFORK
Traits
- From
Clvm - Layer
- An individual layer in a puzzle’s hierarchy.
- Mod
- This trait makes it possible to get the mod hash or puzzle reveal of a puzzle.
- Spend
With Conditions - ToClvm
- ToTree
Hash