pub struct Conditions<T = NodePtr> { /* private fields */ }Expand description
A grow-only list of conditions which can be used when building spend bundles.
Implementations
Sourceimpl Conditions
impl Conditions
Sourcepub fn new() -> Conditions
pub fn new() -> Conditions
Create a new empty list of conditions. To make inference easier for the compiler,
the generic type defaults to NodePtr, since that’s the most general choice
and common when building spend bundles.
If you need to create an instance with a different generic type, use Conditions::default instead.
Sourceimpl<T> Conditions<T>
impl<T> Conditions<T>
Sourcepub fn iter(&self) -> impl Iterator<Item = &Condition<T>>
pub fn iter(&self) -> impl Iterator<Item = &Condition<T>>
Gets an iterator over the conditions.
Sourcepub fn with(self, condition: impl Into<Condition<T>>) -> Conditions<T>
pub fn with(self, condition: impl Into<Condition<T>>) -> Conditions<T>
Adds a condition and returns the updated list.
Sourcepub fn extend(
self,
conditions: impl IntoIterator<Item = impl Into<Condition<T>>>,
) -> Conditions<T>
pub fn extend( self, conditions: impl IntoIterator<Item = impl Into<Condition<T>>>, ) -> Conditions<T>
Appends a list of conditions to the end from an iterator.
Sourcepub fn extend_from_slice(self, conditions: &[Condition<T>]) -> Conditions<T>where
T: Clone,
pub fn extend_from_slice(self, conditions: &[Condition<T>]) -> Conditions<T>where
T: Clone,
Appends a list of conditions to the end from a slice.
Sourceimpl<T> Conditions<T>
impl<T> Conditions<T>
pub fn remark(self, rest: T) -> Conditions<T>
pub fn agg_sig_parent( self, public_key: PublicKey, message: Bytes, ) -> Conditions<T>
pub fn agg_sig_puzzle( self, public_key: PublicKey, message: Bytes, ) -> Conditions<T>
pub fn agg_sig_amount( self, public_key: PublicKey, message: Bytes, ) -> Conditions<T>
pub fn agg_sig_puzzle_amount( self, public_key: PublicKey, message: Bytes, ) -> Conditions<T>
pub fn agg_sig_parent_amount( self, public_key: PublicKey, message: Bytes, ) -> Conditions<T>
pub fn agg_sig_parent_puzzle( self, public_key: PublicKey, message: Bytes, ) -> Conditions<T>
pub fn agg_sig_unsafe( self, public_key: PublicKey, message: Bytes, ) -> Conditions<T>
pub fn agg_sig_me(self, public_key: PublicKey, message: Bytes) -> Conditions<T>
pub fn create_coin( self, puzzle_hash: BytesImpl<32>, amount: u64, memos: Memos<T>, ) -> Conditions<T>
pub fn reserve_fee(self, amount: u64) -> Conditions<T>
pub fn create_coin_announcement(self, message: Bytes) -> Conditions<T>
pub fn assert_coin_announcement( self, announcement_id: BytesImpl<32>, ) -> Conditions<T>
pub fn create_puzzle_announcement(self, message: Bytes) -> Conditions<T>
pub fn assert_puzzle_announcement( self, announcement_id: BytesImpl<32>, ) -> Conditions<T>
pub fn assert_concurrent_spend(self, coin_id: BytesImpl<32>) -> Conditions<T>
pub fn assert_concurrent_puzzle( self, puzzle_hash: BytesImpl<32>, ) -> Conditions<T>
pub fn send_message( self, mode: u8, message: Bytes, data: Vec<T>, ) -> Conditions<T>
pub fn receive_message( self, mode: u8, message: Bytes, data: Vec<T>, ) -> Conditions<T>
pub fn assert_my_coin_id(self, coin_id: BytesImpl<32>) -> Conditions<T>
pub fn assert_my_parent_id(self, parent_id: BytesImpl<32>) -> Conditions<T>
pub fn assert_my_puzzle_hash(self, puzzle_hash: BytesImpl<32>) -> Conditions<T>
pub fn assert_my_amount(self, amount: u64) -> Conditions<T>
pub fn assert_my_birth_seconds(self, seconds: u64) -> Conditions<T>
pub fn assert_my_birth_height(self, height: u32) -> Conditions<T>
pub fn assert_ephemeral(self) -> Conditions<T>
pub fn assert_seconds_relative(self, seconds: u64) -> Conditions<T>
pub fn assert_seconds_absolute(self, seconds: u64) -> Conditions<T>
pub fn assert_height_relative(self, height: u32) -> Conditions<T>
pub fn assert_height_absolute(self, height: u32) -> Conditions<T>
pub fn assert_before_seconds_relative(self, seconds: u64) -> Conditions<T>
pub fn assert_before_seconds_absolute(self, seconds: u64) -> Conditions<T>
pub fn assert_before_height_relative(self, height: u32) -> Conditions<T>
pub fn assert_before_height_absolute(self, height: u32) -> Conditions<T>
pub fn softfork(self, cost: u64, rest: T) -> Conditions<T>
pub fn transfer_nft( self, launcher_id: Option<BytesImpl<32>>, trade_prices: Vec<TradePrice>, singleton_inner_puzzle_hash: Option<BytesImpl<32>>, ) -> Conditions<T>
pub fn run_cat_tail(self, program: T, solution: T) -> Conditions<T>
pub fn melt_singleton(self) -> Conditions<T>
pub fn update_nft_metadata( self, updater_puzzle_reveal: T, updater_solution: T, ) -> Conditions<T>
pub fn update_data_store_merkle_root( self, new_merkle_root: BytesImpl<32>, memos: Vec<Bytes>, ) -> Conditions<T>