Crate dig_clvm

Crate dig_clvm 

dig-clvm: DIG L2 CLVM Consensus Engine

Validates spend bundles and computes coin additions/removals for DIG validators. Built as a thin orchestration layer on top of the Chia crate ecosystem.

Re-exports

pub use consensus::build_block_generator;
pub use consensus::validate_block;
pub use consensus::validate_spend_bundle;
pub use consensus::BlockGeneratorResult;
pub use consensus::SpendResult;
pub use consensus::ValidationConfig;
pub use consensus::ValidationContext;
pub use consensus::ValidationError;
pub use consensus::L1_MAX_COST_PER_SPEND;
pub use consensus::L2_MAX_COST_PER_BLOCK;
pub use clvm_traits;
pub use clvm_utils;
pub use clvmr;
pub use chia_protocol;
pub use chia_consensus;
pub use chia_bls;
pub use chia_sdk_types;
pub use dig_constants;
pub use chia_sdk_driver;
pub use chia_sdk_coinset;
pub use chia_puzzles;

Modules

consensus
L2 consensus orchestration.
opcodes

Structs

Allocator
BlsCache
Bytes
Coin
CoinRecord
CoinSpend
CoinState
Conditions
A grow-only list of conditions which can be used when building spend bundles.
ConsensusConstants
CurriedProgram
NetworkConstants
DIG network constants.
NodePtr
Program
PublicKey
SecretKey
Signature
Spend
SpendBundle
SpendContext
A wrapper around Allocator that caches puzzles and keeps track of a list of CoinSpend. It’s used to construct spend bundles in an easy and efficient way.
TreeHash

Enums

Condition
DriverError
Puzzle

Constants

AGG_SIG_AMOUNT
AGG_SIG_COST
AGG_SIG_ME
AGG_SIG_PARENT
AGG_SIG_PARENT_AMOUNT
AGG_SIG_PARENT_PUZZLE
AGG_SIG_PUZZLE
AGG_SIG_PUZZLE_AMOUNT
AGG_SIG_UNSAFE
ASSERT_BEFORE_HEIGHT_ABSOLUTE
ASSERT_BEFORE_HEIGHT_RELATIVE
ASSERT_BEFORE_SECONDS_ABSOLUTE
ASSERT_BEFORE_SECONDS_RELATIVE
ASSERT_COIN_ANNOUNCEMENT
ASSERT_CONCURRENT_PUZZLE
ASSERT_CONCURRENT_SPEND
ASSERT_EPHEMERAL
ASSERT_HEIGHT_ABSOLUTE
ASSERT_HEIGHT_RELATIVE
ASSERT_MY_AMOUNT
ASSERT_MY_BIRTH_HEIGHT
ASSERT_MY_BIRTH_SECONDS
ASSERT_MY_COIN_ID
ASSERT_MY_PARENT_ID
ASSERT_MY_PUZZLEHASH
ASSERT_PUZZLE_ANNOUNCEMENT
ASSERT_SECONDS_ABSOLUTE
ASSERT_SECONDS_RELATIVE
CREATE_COIN
CREATE_COIN_ANNOUNCEMENT
CREATE_COIN_COST
CREATE_PUZZLE_ANNOUNCEMENT
DIG_MAINNET
DIG mainnet constants.
DIG_TESTNET
DIG testnet constants.
FREE_CONDITIONS
GENERIC_CONDITION_COST
RECEIVE_MESSAGE
REMARK
RESERVE_FEE
SEND_MESSAGE
SOFTFORK

Traits

FromClvm
Layer
An individual layer in a puzzle’s hierarchy.
Mod
This trait makes it possible to get the mod hash or puzzle reveal of a puzzle.
SpendWithConditions
ToClvm
ToTreeHash

Functions

aggregate_verify
compute_unknown_condition_cost
parse_opcode
tree_hash

Type Aliases

Bytes32
ConditionOpcode
Cost

Derive Macros

FromClvm
ToClvm