dig-clvm: DIG L2 CLVM Consensus Engine
Validates spend bundles and computes coin additions/removals for DIG validators. Built as a thin orchestration layer on top of the Chia crate ecosystem.
Re-exports
pub use consensus::build_block_generator;pub use consensus::validate_block;pub use consensus::validate_spend_bundle;pub use consensus::BlockGeneratorResult;pub use consensus::SpendResult;pub use consensus::ValidationConfig;pub use consensus::ValidationContext;pub use consensus::ValidationError;pub use consensus::L1_MAX_COST_PER_SPEND;pub use consensus::L2_MAX_COST_PER_BLOCK;pub use clvm_traits;pub use clvm_utils;pub use clvmr;pub use chia_protocol;pub use chia_consensus;pub use chia_bls;pub use chia_sdk_types;pub use dig_constants;pub use chia_sdk_driver;pub use chia_sdk_coinset;pub use chia_puzzles;
Modules
Structs
- Allocator
- BlsCache
- Bytes
- Coin
- Coin
Record - Coin
Spend - Coin
State - Conditions
- A grow-only list of conditions which can be used when building spend bundles.
- Consensus
Constants - Curried
Program - Network
Constants - DIG network constants.
- NodePtr
- Program
- Public
Key - Secret
Key - Signature
- Spend
- Spend
Bundle - Spend
Context - A wrapper around
Allocatorthat caches puzzles and keeps track of a list ofCoinSpend. It’s used to construct spend bundles in an easy and efficient way. - Tree
Hash
Enums
Constants
- DIG_
MAINNET - DIG mainnet constants.
- DIG_
TESTNET - DIG testnet constants.
Traits
- From
Clvm - Layer
- An individual layer in a puzzle’s hierarchy.
- Mod
- This trait makes it possible to get the mod hash or puzzle reveal of a puzzle.
- Spend
With Conditions - ToClvm
- ToTree
Hash