pub struct ConsensusConstants {Show 55 fields
pub slot_blocks_target: u32,
pub min_blocks_per_challenge_block: u8,
pub max_sub_slot_blocks: u32,
pub num_sps_sub_slot: u8,
pub sub_slot_iters_starting: u64,
pub difficulty_constant_factor: u128,
pub difficulty_starting: u64,
pub difficulty_change_max_factor: u32,
pub sub_epoch_blocks: u32,
pub epoch_blocks: u32,
pub significant_bits: u8,
pub discriminant_size_bits: u16,
pub number_zero_bits_plot_filter_v1: u8,
pub number_zero_bits_plot_filter_v2: u8,
pub min_plot_size_v1: u8,
pub max_plot_size_v1: u8,
pub min_plot_size_v2: u8,
pub max_plot_size_v2: u8,
pub sub_slot_time_target: u16,
pub num_sp_intervals_extra: u8,
pub max_future_time2: u32,
pub number_of_timestamps: u8,
pub genesis_challenge: BytesImpl<32>,
pub agg_sig_me_additional_data: BytesImpl<32>,
pub agg_sig_parent_additional_data: BytesImpl<32>,
pub agg_sig_puzzle_additional_data: BytesImpl<32>,
pub agg_sig_amount_additional_data: BytesImpl<32>,
pub agg_sig_puzzle_amount_additional_data: BytesImpl<32>,
pub agg_sig_parent_amount_additional_data: BytesImpl<32>,
pub agg_sig_parent_puzzle_additional_data: BytesImpl<32>,
pub genesis_pre_farm_pool_puzzle_hash: BytesImpl<32>,
pub genesis_pre_farm_farmer_puzzle_hash: BytesImpl<32>,
pub max_vdf_witness_size: u8,
pub mempool_block_buffer: u8,
pub max_coin_amount: u64,
pub max_block_cost_clvm: u64,
pub cost_per_byte: u64,
pub weight_proof_threshold: u8,
pub weight_proof_recent_blocks: u32,
pub max_block_count_per_requests: u32,
pub blocks_cache_size: u32,
pub max_generator_size: u32,
pub max_generator_ref_list_size: u32,
pub pool_sub_slot_iters: u64,
pub hard_fork_height: u32,
pub hard_fork2_height: u32,
pub plot_filter_128_height: u32,
pub plot_filter_64_height: u32,
pub plot_filter_32_height: u32,
pub plot_difficulty_initial: u8,
pub plot_difficulty_4_height: u32,
pub plot_difficulty_5_height: u32,
pub plot_difficulty_6_height: u32,
pub plot_difficulty_7_height: u32,
pub plot_difficulty_8_height: u32,
}Fields
slot_blocks_target: u32How many blocks to target per sub-slot.
min_blocks_per_challenge_block: u8How many blocks must be created per slot (to make challenge sb).
max_sub_slot_blocks: u32Max number of blocks that can be infused into a sub-slot. Note: This must be less than SUB_EPOCH_BLOCKS/2, and > SLOT_BLOCKS_TARGET.
num_sps_sub_slot: u8The number of signage points per sub-slot (including the 0th sp at the sub-slot start).
sub_slot_iters_starting: u64The sub_slot_iters for the first epoch.
difficulty_constant_factor: u128Multiplied by the difficulty to get iterations.
difficulty_starting: u64The difficulty for the first epoch.
difficulty_change_max_factor: u32The maximum factor by which difficulty and sub_slot_iters can change per epoch.
sub_epoch_blocks: u32The number of blocks per sub-epoch.
epoch_blocks: u32The number of blocks per sub-epoch, must be a multiple of SUB_EPOCH_BLOCKS.
significant_bits: u8The number of bits to look at in difficulty and min iters. The rest are zeroed.
discriminant_size_bits: u16Max is 1024 (based on ClassGroupElement int size).
number_zero_bits_plot_filter_v1: u8H(plot id + challenge hash + signage point) must start with these many zeroes. This applies to original plots, and proof-of-space format
number_zero_bits_plot_filter_v2: u8H(plot id + challenge hash + signage point) must start with these many zeroes. This applies to the new plot format, and proof-of-space format
min_plot_size_v1: u8The smallest and largest allowed plot size for the original plot format, v1. These are the K-values for the plots.
max_plot_size_v1: u8min_plot_size_v2: u8The smallest and largest allowed plot size for the the new plot format, v2. These are the K-values for the plots. In addition to these constraints, v2 plot sizes must be even numbers. The new plot format was introduced in Chia-3.0.
max_plot_size_v2: u8sub_slot_time_target: u16The target number of seconds per sub-slot.
num_sp_intervals_extra: u8The difference between signage point and infusion point (plus required_iters).
max_future_time2: u32After soft-fork2, this is the new MAX_FUTURE_TIME.
number_of_timestamps: u8Than the average of the last NUMBER_OF_TIMESTAMPS blocks.
genesis_challenge: BytesImpl<32>Used as the initial cc rc challenges, as well as first block back pointers, and first SES back pointer. We override this value based on the chain being run (testnet0, testnet1, mainnet, etc).
agg_sig_me_additional_data: BytesImpl<32>Forks of chia should change these values to provide replay attack protection.
agg_sig_parent_additional_data: BytesImpl<32>By convention, the below additional data is derived from the agg_sig_me_additional_data
agg_sig_puzzle_additional_data: BytesImpl<32>agg_sig_amount_additional_data: BytesImpl<32>agg_sig_puzzle_amount_additional_data: BytesImpl<32>agg_sig_parent_amount_additional_data: BytesImpl<32>agg_sig_parent_puzzle_additional_data: BytesImpl<32>genesis_pre_farm_pool_puzzle_hash: BytesImpl<32>The block at height must pay out to this pool puzzle hash.
genesis_pre_farm_farmer_puzzle_hash: BytesImpl<32>The block at height must pay out to this farmer puzzle hash.
max_vdf_witness_size: u8The maximum number of classgroup elements within an n-wesolowski proof.
mempool_block_buffer: u8Size of mempool = 10x the size of block.
max_coin_amount: u64Max coin amount uint(1 << 64). This allows coin amounts to fit in 64 bits. This is around 18M chia.
max_block_cost_clvm: u64Max block cost in clvm cost units.
cost_per_byte: u64Cost per byte of generator program.
weight_proof_threshold: u8weight_proof_recent_blocks: u32max_block_count_per_requests: u32blocks_cache_size: u32max_generator_size: u32max_generator_ref_list_size: u32pool_sub_slot_iters: u64hard_fork_height: u32The hard fork planned with the 2.0 release. This is the block with the first plot filter adjustment.
hard_fork2_height: u32The hard fork planned with the 3.0 release. This is the first block where the new plot format and proof-of-space is valid
plot_filter_128_height: u32The 128 plot filter adjustment height. This affects the plot filter for original plots
plot_filter_64_height: u32The 64 plot filter adjustment height. This affects the plot filter for original plots
plot_filter_32_height: u32The 32 plot filter adjustment height. This affects the plot filter for original plots
plot_difficulty_initial: u8initial plot difficulty for the v2 plot format.
plot_difficulty_4_height: u32Plot difficulty is a feature of the new plot format, v2 (introduced in Chia 3.0) The plot difficulty will increase at these block heights. The new difficulty will be 4, 5, 6, 7 and 8 respectively.
plot_difficulty_5_height: u32plot_difficulty_6_height: u32plot_difficulty_7_height: u32plot_difficulty_8_height: u32Implementations
Sourceimpl ConsensusConstants
impl ConsensusConstants
pub fn new( slot_blocks_target: u32, min_blocks_per_challenge_block: u8, max_sub_slot_blocks: u32, num_sps_sub_slot: u8, sub_slot_iters_starting: u64, difficulty_constant_factor: u128, difficulty_starting: u64, difficulty_change_max_factor: u32, sub_epoch_blocks: u32, epoch_blocks: u32, significant_bits: u8, discriminant_size_bits: u16, number_zero_bits_plot_filter_v1: u8, number_zero_bits_plot_filter_v2: u8, min_plot_size_v1: u8, max_plot_size_v1: u8, min_plot_size_v2: u8, max_plot_size_v2: u8, sub_slot_time_target: u16, num_sp_intervals_extra: u8, max_future_time2: u32, number_of_timestamps: u8, genesis_challenge: BytesImpl<32>, agg_sig_me_additional_data: BytesImpl<32>, agg_sig_parent_additional_data: BytesImpl<32>, agg_sig_puzzle_additional_data: BytesImpl<32>, agg_sig_amount_additional_data: BytesImpl<32>, agg_sig_puzzle_amount_additional_data: BytesImpl<32>, agg_sig_parent_amount_additional_data: BytesImpl<32>, agg_sig_parent_puzzle_additional_data: BytesImpl<32>, genesis_pre_farm_pool_puzzle_hash: BytesImpl<32>, genesis_pre_farm_farmer_puzzle_hash: BytesImpl<32>, max_vdf_witness_size: u8, mempool_block_buffer: u8, max_coin_amount: u64, max_block_cost_clvm: u64, cost_per_byte: u64, weight_proof_threshold: u8, weight_proof_recent_blocks: u32, max_block_count_per_requests: u32, blocks_cache_size: u32, max_generator_size: u32, max_generator_ref_list_size: u32, pool_sub_slot_iters: u64, hard_fork_height: u32, hard_fork2_height: u32, plot_filter_128_height: u32, plot_filter_64_height: u32, plot_filter_32_height: u32, plot_difficulty_initial: u8, plot_difficulty_4_height: u32, plot_difficulty_5_height: u32, plot_difficulty_6_height: u32, plot_difficulty_7_height: u32, plot_difficulty_8_height: u32, ) -> ConsensusConstants